@@ -4,11 +4,11 @@ import (
 	"errors"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 )
 
 type CfTarget struct {
-	base
+	Base
 
 	CfTargetDetails
 }
@@ -29,12 +29,12 @@ func (c *CfTarget) Enabled() bool {
 		return false
 	}
 
-	displayMode := c.props.GetString(DisplayMode, DisplayModeAlways)
+	displayMode := c.options.String(DisplayMode, DisplayModeAlways)
 	if displayMode != DisplayModeFiles {
 		return c.setCFTargetStatus()
 	}
 
-	files := c.props.GetStringArray(properties.Files, []string{"manifest.yml"})
+	files := c.options.StringArray(options.Files, []string{"manifest.yml"})
 	for _, file := range files {
 		manifest, err := c.env.HasParentFilePath(file, false)
 		if err != nil || manifest.IsDir {
